#[non_exhaustive]pub enum AudioDataFormat {
InterleavedF32 {
channel_count: u16,
sample_rate: u32,
total_duration: Option<Duration>,
},
FileExtension(Txt),
MimeType(Txt),
Unknown,
}Expand description
Format of the audio bytes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InterleavedF32
Data is already decoded stream of interleaved f32 samples.
Fields
FileExtension(Txt)
The audio is encoded.
This file extension maybe identifies the format. Fallback to Unknown handling if the file extension
is unknown or the file header does not match.
MimeType(Txt)
The audio is encoded.
This MIME type maybe identifies the format. Fallback to Unknown handling if the file extension
is unknown or the file header does not match.
Unknown
The image is encoded.
A decoder will be selected using the “magic number” at the start of the bytes buffer.