#[non_exhaustive]pub enum AudioMixLayer {
Audio {
audio: AudioId,
skip: Duration,
take: Duration,
},
AudioMix {
mix: AudioMix,
skip: Duration,
take: Duration,
},
VolumeLinear {
start: Duration,
duration: Duration,
start_volume: Factor,
end_volume: Factor,
},
SineWave {
frequency: f32,
duration: Duration,
},
}Expand description
Represents an audio source component.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Audio
Play the cached audio.
The audio samples are adapted to the output format and added to the under layers result.
Fields
skip: DurationClip the start of the audio.
Set to Duration::ZERO to play from the start.
take: DurationClip the end of the audio. Does not add padding, if skip + take is greater than the audio length stops early.
Set to Duration::MAX to play to the end.
AudioMix
Play the mix.
This mix is sampled as an audio (computed), its effect layers do not affect the parent mix.
Fields
skip: DurationClip the start of the audio.
Set to Duration::ZERO to play from the start.
take: DurationClip the end of the audio. Does not add padding, if skip + take is greater than the audio length stops early.
Set to Duration::MAX to play to the end.
VolumeLinear
Linear volume transition.
When the playback is in range the volume is multiplied by the linear interpolation between start_volume and end_volume. The volume snaps
back to the output stream volume after the end, unless another volume control layer is in effect.
Fields
SineWave
Generate a sine wave sound.