#[non_exhaustive]pub struct AudioMix {
pub delay: Duration,
pub total_duration: Option<Duration>,
pub layers: Vec<AudioMixLayer>,
}Expand description
Represents an audio source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delay: DurationSilent start padding.
total_duration: Option<Duration>Total duration.
If not set audio plays until the last layer. If set audio plays for the duration, if layers end before the duration plays silent, if layers exceed the duration the end is clipped.
layers: Vec<AudioMixLayer>Components of this mix.
Each layer applies to the previous.
Implementations