pub struct AudioOutputId(/* private fields */);Expand description
Audio playback stream ID.
In the View Process this is mapped to a system id.
In the App Process this is an unique id that survives View crashes.
The App Process defines the ID.
Implementations