#[non_exhaustive]pub struct AudioRequest<D> {
pub format: AudioDataFormat,
pub data: D,
pub max_decoded_len: u64,
pub tracks: AudioTracksMode,
pub parent: Option<AudioTrackMetadata>,
}Expand description
Represent an audio load/decode request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.format: AudioDataFormatAudio data format.
data: DAudio data.
max_decoded_len: u64Maximum allowed decoded size in bytes.
View-process will avoid decoding and return an error if the track would exceed this limit.
tracks: AudioTracksModeDefines what tracks are decoded from multi image containers.
parent: Option<AudioTrackMetadata>Audio is a track (or subtree) of this other audio.
This value is now used by the view-process, it is just returned with the metadata. This is useful when an already decoded image is requested after a respawn to maintain the original container structure.
Implementations
Sourceimpl<D> AudioRequest<D>
impl<D> AudioRequest<D>
Sourcepub fn new(format: AudioDataFormat, data: D, max_decoded_len: u64) -> Self
pub fn new(format: AudioDataFormat, data: D, max_decoded_len: u64) -> Self
New.