#[non_exhaustive]pub struct AudioTrackMetadata {
pub parent: AudioId,
pub index: usize,
}Expand description
Represents decoded header metadata about a track position in the container represented by another audio.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: AudioIdImage this one belongs too.
The view-process always sends the parent image metadata first, so this id should be known by the app-process.
index: usizeSort index of the track in the list of tracks.
Implementations