#[non_exhaustive]pub enum NotificationResponse {
Action(Txt),
Dismissed,
Removed,
Error(Txt),
}Expand description
Response to a notification dialog.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Action(Txt)
User requested an action.
The associated text is the NotificationAction::id.
The associated text can be empty indicating the user requested general action, usually by tapping the message directly and not another an action button.
Dismissed
User dismissed the notification without requesting an action.
Removed
Programmatically removed. Can be due to timeout or any other reason.
Error(Txt)
Failed to show the notification.
The associated text may contain debug information.