#[non_exhaustive]pub enum ImageDownscaleMode {
Fit(PxSize),
Fill(PxSize),
MipMap {
min_size: PxSize,
max_size: PxSize,
},
Entries(Vec<ImageDownscaleMode>),
}Expand description
Defines how an image is downscaled after decoding.
The image aspect ratio is preserved in all modes. The image is never upscaled. If the image container contains reduced alternative the nearest to the requested size is used as source.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Fit(PxSize)
Image is downscaled so that both dimensions fit inside the size.
Fill(PxSize)
Image is downscaled so that at least one dimension fits inside the size. The image is not clipped.
MipMap
Generate synthetic ImageEntryKind::Reduced entries each half the size of the image until the sample that is
nearest min_size and greater or equal to it. If the image container already has alternates that are equal to
or near a mip size that size is used instead.
Entries(Vec<ImageDownscaleMode>)
Generate multiple synthetic ImageEntryKind::Reduced entries. The entry sizes are sorted by largest first,
if the image full size already fits in the largest downscale requested the full image is returned and any
downscale actually smaller becomes a synthetic entry. If the image is larger than all requested sizes it is downscaled as well.
Implementations
Sourceimpl ImageDownscaleMode
impl ImageDownscaleMode
Sourcepub fn mip_map() -> Self
pub fn mip_map() -> Self
Default mipmap min/max when the objective of the mipmap is optimizing dynamically resizing massive images.
Sourcepub fn with_entry(self, other: impl Into<ImageDownscaleMode>) -> Self
pub fn with_entry(self, other: impl Into<ImageDownscaleMode>) -> Self
Append entry downscale request.
Sourcepub fn sizes(
&self,
page_size: PxSize,
reduced_sizes: &[PxSize],
) -> (Option<PxSize>, Vec<PxSize>)
pub fn sizes( &self, page_size: PxSize, reduced_sizes: &[PxSize], ) -> (Option<PxSize>, Vec<PxSize>)
Get downscale sizes that need to be generated.
The page_size is the image full size, the reduced_sizes are
sizes of reduced alternates that are already provided by the image container.
Returns the downscale for the image full size, if needed and a list of reduced entries that must be synthesized, sorted largest to smallest.