#[non_exhaustive]pub enum PartialImageKind {
Placeholder {
pixel_size: PxSize,
},
Rows {
y: Px,
height: Px,
},
}Expand description
Represents what kind of partial data was decoded.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Placeholder
The pixels are a placeholder image that must fill the actual image size.
Rows
The pixels is an image with the image full width but with only height.