#[non_exhaustive]pub struct ImageDecoded {
pub meta: ImageMetadata,
pub partial: Option<PartialImageKind>,
pub pixels: IpcBytes,
pub is_opaque: bool,
}Expand description
Represents a partial or fully decoded image.
See Event::ImageDecoded for more details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: ImageMetadataImage metadata.
partial: Option<PartialImageKind>If the pixels only represent a partial image.
When this is None the image has fully loaded.
pixels: IpcBytesDecoded pixels.
Is BGRA8 pre-multiplied if !is_mask or is A8 if is_mask.
is_opaque: boolIf all pixels have an alpha value of 255.
Implementations
Sourceimpl ImageDecoded
impl ImageDecoded
Sourcepub fn new(meta: ImageMetadata, pixels: IpcBytes, is_opaque: bool) -> Self
pub fn new(meta: ImageMetadata, pixels: IpcBytes, is_opaque: bool) -> Self
New.