#[non_exhaustive]pub struct ImageEncodeRequest {
pub id: ImageId,
pub entries: Vec<(ImageId, ImageEntryKind)>,
pub format: Txt,
}Expand description
Represent a image encode request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: ImageIdImage to encode.
entries: Vec<(ImageId, ImageEntryKind)>Optional entries to also encode.
If set encodes the id as the first page followed by each entry in the order given.
format: TxtFormat query, view-process uses ImageFormat::matches to find the format.
Implementations