#[non_exhaustive]pub struct ImageEntryMetadata {
pub parent: ImageId,
pub index: usize,
pub kind: ImageEntryKind,
}Expand description
Represents decoded header metadata about an image position in a container represented by another image.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: ImageIdImage this one belongs too.
The view-process always sends the parent image metadata first, so this id should be known by the app-process.
index: usizeSort index of the image in the list of entries.
kind: ImageEntryKindKind of entry.
Implementations
Sourceimpl ImageEntryMetadata
impl ImageEntryMetadata
Sourcepub fn new(parent: ImageId, index: usize, kind: ImageEntryKind) -> Self
pub fn new(parent: ImageId, index: usize, kind: ImageEntryKind) -> Self
New.