#[non_exhaustive]pub struct ImageFormat {
pub display_name: Txt,
pub media_type_suffixes: Txt,
pub file_extensions: Txt,
pub magic_numbers: Txt,
pub capabilities: ImageFormatCapability,
}Expand description
Represents an image codec capability.
This type will be used in the next breaking release of the view API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: TxtDisplay name of the format.
media_type_suffixes: TxtMedia types (MIME) associated with the format.
Lowercase, without "image/" prefix, comma separated if there is more than one.
file_extensions: TxtCommon file extensions associated with the format.
Lowercase, without dot, comma separated if there is more than one.
magic_numbers: TxtIdentifier file prefixes.
Lower case ASCII hexadecimals, comma separated if there is more than one, "xx" matches any byte.
capabilities: ImageFormatCapabilityCapabilities of this format.
Implementations
Sourceimpl ImageFormat
impl ImageFormat
Sourcepub const fn from_static(
display_name: &'static str,
media_type_suffixes: &'static str,
file_extensions: &'static str,
capabilities: ImageFormatCapability,
) -> Self
👎Deprecated: use from_static2, it will replace this function next breaking release
pub const fn from_static( display_name: &'static str, media_type_suffixes: &'static str, file_extensions: &'static str, capabilities: ImageFormatCapability, ) -> Self
from_static2, it will replace this function next breaking releaseSourcepub const fn from_static2(
display_name: &'static str,
media_type_suffixes: &'static str,
file_extensions: &'static str,
magic_numbers: &'static str,
capabilities: ImageFormatCapability,
) -> Self
pub const fn from_static2( display_name: &'static str, media_type_suffixes: &'static str, file_extensions: &'static str, magic_numbers: &'static str, capabilities: ImageFormatCapability, ) -> Self
Sourcepub fn media_type_suffixes_iter(&self) -> impl Iterator<Item = &str>
pub fn media_type_suffixes_iter(&self) -> impl Iterator<Item = &str>
Iterate over media type suffixes.
Sourcepub fn media_types(&self) -> impl Iterator<Item = Txt>
pub fn media_types(&self) -> impl Iterator<Item = Txt>
Iterate over full media types, with "image/" prefix.
Sourcepub fn file_extensions_iter(&self) -> impl Iterator<Item = &str>
pub fn file_extensions_iter(&self) -> impl Iterator<Item = &str>
Iterate over extensions.
Sourcepub fn matches(&self, f: &str) -> bool
pub fn matches(&self, f: &str) -> bool
Checks if f matches any of the mime types or any of the file extensions.
File extensions comparison ignores dot and ASCII case.
Sourcepub fn matches_magic(&self, file_prefix: &[u8]) -> bool
pub fn matches_magic(&self, file_prefix: &[u8]) -> bool
Check if file_prefix matches any magic numbers.
A good size for file_prefix is 24 bytes, it should cover all image formats.