#[non_exhaustive]pub struct ImageMetadata {
pub id: ImageId,
pub size: PxSize,
pub density: Option<PxDensity2d>,
pub is_mask: bool,
pub original_color_type: ColorType,
pub parent: Option<ImageEntryMetadata>,
}Expand description
Represents decoded header metadata about an image.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: ImageIdImage ID.
size: PxSizePixel size.
density: Option<PxDensity2d>Pixel density metadata.
is_mask: boolIf the pixels are in a single channel (A8).
original_color_type: ColorTypeImage color type before it was converted to BGRA8 or A8.
parent: Option<ImageEntryMetadata>Extra metadata if this image is an entry in another image.
When this is None the is the first ImageEntryKind::Page in the container, usually the only page.
Implementations