#[non_exhaustive]pub struct TrayIcon {
pub icon: ImageId,
pub context_menu: Vec<MenuItem>,
pub primary_command_id: Txt,
}Expand description
Represents a tray icon status indicator.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.icon: ImageIdIcon image.
The tray icon will only be inserted when this image is valid and loaded.
Optional context menu.
If not empty a context menu shows on context clock.
primary_command_id: TxtA command ID for a primary click on the icon.
If set an Event::MenuCommand notifies on click, otherwise the context menu also opens on primary click.
Implementations