#[non_exhaustive]pub enum VideoDataFormat {
FileExtension(Txt),
MimeType(Txt),
Unknown,
}Expand description
Format of the video bytes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FileExtension(Txt)
The video is encoded.
This file extension maybe identifies the format. Fallback to Unknown handling if the file extension
is unknown or the file header does not match.
MimeType(Txt)
The video is encoded.
This MIME type maybe identifies the format. Fallback to Unknown handling if the file extension
is unknown or the file header does not match.
Unknown
The image is encoded.
A decoder will be selected using the “magic number” at the start of the bytes buffer.