#[non_exhaustive]pub struct MonitorInfo {
pub name: Txt,
pub position: PxPoint,
pub size: PxSize,
pub scale_factor: Factor,
pub video_modes: Vec<VideoMode>,
pub is_primary: bool,
}Expand description
Information about a monitor screen.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: TxtReadable name of the monitor.
position: PxPointTop-left offset of the monitor region in the virtual screen, in pixels.
size: PxSizeWidth/height of the monitor region in the virtual screen, in pixels.
scale_factor: FactorThe monitor scale factor.
video_modes: Vec<VideoMode>Exclusive fullscreen video modes.
is_primary: boolIf could determine this monitor is the primary.
Implementations