#[non_exhaustive]pub struct AudioDecoded {
pub id: AudioId,
pub offset: usize,
pub chunk: IpcBytesCast<f32>,
pub is_full: bool,
}Expand description
Represents a partial or fully decoded audio.
See Event::AudioDecoded for more details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: AudioIdThe audio track ID.
An AudioMetadata for this ID was already notified before this event.
offset: usizeOffset of the chunk on the track.
This is a count in samples before the first in this chunk, a sample is a sequence of channel_count.
To convert offset to bytes offset * channel_count * size_of::<f32>().
chunk: IpcBytesCast<f32>Interleaved f32 samples.
is_full: boolIf the chunk is actually the full decoded audio.
When this is true no more decode events for the id are send, (re)playing the audio
will read directly from the cache.
When this is false the chunk represent the last decoded chunk on demand because the audio is playing.
Depending on the request the audio may never be fully cached, always decoding again on replay.
Implementations
Sourceimpl AudioDecoded
impl AudioDecoded
Sourcepub fn new(id: AudioId, chunk: IpcBytesCast<f32>) -> Self
pub fn new(id: AudioId, chunk: IpcBytesCast<f32>) -> Self
New.