#[non_exhaustive]pub enum ImageEntryKind {
Page,
Reduced {
synthetic: bool,
},
Other {
kind: Txt,
},
}Expand description
Kind of image container entry an image was decoded from.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Page
Full sized image in the container.
Reduced
Reduced resolution alternate of the other image.
Can be mip levels, a thumbnail or a smaller symbolic alternative designed to be more readable at smaller scale.
Other
Custom kind identifier.