#[non_exhaustive]pub struct ImageRequest<D> {
pub format: ImageDataFormat,
pub data: D,
pub max_decoded_len: u64,
pub downscale: Option<ImageDownscaleMode>,
pub mask: Option<ImageMaskMode>,
pub entries: ImageEntriesMode,
pub parent: Option<ImageEntryMetadata>,
}Expand description
Represent a image load/decode request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.format: ImageDataFormatImage data format.
data: DImage data.
Bytes layout depends on the format, data structure is IpcBytes or IpcReceiver<IpcBytes> in the view API.
max_decoded_len: u64Maximum allowed decoded size.
View-process will avoid decoding and return an error if the image decoded to BGRA (4 bytes) exceeds this size.
This limit applies to the image before the downscale.
downscale: Option<ImageDownscaleMode>A size constraints to apply after the image is decoded. The image is resized to fit or fill the given size. Optionally generate multiple reduced entries.
If the image contains multiple images selects the nearest reduced alternate that can be downscaled.
If entries requests REDUCED only the alternates smaller than the requested downscale are included.
mask: Option<ImageMaskMode>Convert or decode the image into a single channel mask (R8).
entries: ImageEntriesModeDefines what images are decoded from multi image containers.
parent: Option<ImageEntryMetadata>Image is an entry (or subtree) of this other image.
This value is now used by the view-process, it is just returned with the metadata. This is useful when an already decoded image is requested after a respawn to maintain the original container structure.
Implementations
Sourceimpl<D> ImageRequest<D>
impl<D> ImageRequest<D>
Sourcepub fn new(
format: ImageDataFormat,
data: D,
max_decoded_len: u64,
downscale: Option<ImageDownscaleMode>,
mask: Option<ImageMaskMode>,
) -> Self
pub fn new( format: ImageDataFormat, data: D, max_decoded_len: u64, downscale: Option<ImageDownscaleMode>, mask: Option<ImageMaskMode>, ) -> Self
New request.