#[non_exhaustive]pub struct ViewProcessInfo {
pub generation: ViewProcessGen,
pub is_respawn: bool,
pub input_device: InputDeviceCapability,
pub window: WindowCapability,
pub dialog: DialogCapability,
pub menu: MenuCapability,
pub clipboard: ClipboardTypes,
pub image: Vec<ImageFormat>,
pub audio: Vec<AudioFormat>,
pub extensions: ApiExtensions,
}Expand description
View-process implementation info.
The view-process implementation may not cover the full API, depending on operating system, build, headless mode. When the view-process does not implement something it just logs an error and ignores the request, this struct contains detailed info about what operations are available in the view-process instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.generation: ViewProcessGenView-process generation, changes after respawns and is never zero.
is_respawn: boolIf the view-process is a respawn from a previous crashed process.
input_device: InputDeviceCapabilityInput device events implemented by the view-process.
window: WindowCapabilityWindow operations implemented by the view-process.
dialog: DialogCapabilityDialog operations implemented by the view-process.
System menu capabilities.
clipboard: ClipboardTypesClipboard data types and operations implemented by the view-process.
image: Vec<ImageFormat>Image decode and encode capabilities implemented by the view-process.
audio: Vec<AudioFormat>Audio decode and encode capabilities implemented by the view-process.
extensions: ApiExtensionsAPI extensions implemented by the view-process.
The extension IDs will stay valid for the duration of the view-process.
Implementations
Sourceimpl ViewProcessInfo
impl ViewProcessInfo
Sourcepub const fn new(generation: ViewProcessGen, is_respawn: bool) -> Self
pub const fn new(generation: ViewProcessGen, is_respawn: bool) -> Self
New response.