Module zng_view_api::window
source · Expand description
Window, surface and frame types.
Structs
- Defines a custom mouse cursor.
Event::FrameRenderedpayload.- Identifier of a frame or frame update.
- Data for rendering a new frame.
- Data for rendering a new frame that is derived from the current frame.
- Identifies a frame request for collaborative resize in
WindowChanged. - Information about a successfully opened headless surface.
- Configuration of a new headless surface.
- Monitor screen ID in channel.
- Information about a monitor screen.
- Exclusive video mode info.
Event::WindowChangedpayload.- Window ID in channel.
- Information about a successfully opened window.
- Configuration of a new window.
- Represents the properties of a window that affect its position, size and state.
Enums
- Describes the appearance of the mouse cursor.
- Cause of a window state change.
- Represents a focus request indicator.
- Frame image capture request.
- Render backend preference.
- Window state.