pub struct WindowCapability(/* private fields */);Expand description
Window operations the view-process implements.
Implementations
Sourceimpl WindowCapability
impl WindowCapability
Sourcepub const SET_VISIBLE: Self
pub const SET_VISIBLE: Self
Can set window visible.
Sourcepub const SET_ALWAYS_ON_TOP: Self
pub const SET_ALWAYS_ON_TOP: Self
Can make window “topmost”.
Sourcepub const SET_MOVABLE: Self
pub const SET_MOVABLE: Self
Can change if window can be dragged by the user.
Sourcepub const SET_RESIZABLE: Self
pub const SET_RESIZABLE: Self
Can change if window can be resized by the user.
Sourcepub const SET_TASKBAR_VISIBLE: Self
pub const SET_TASKBAR_VISIBLE: Self
Can make window icon not appear on the taskbar while the window remains visible.
Sourcepub const BRING_TO_TOP: Self
pub const BRING_TO_TOP: Self
Can force window to appear in front of other apps, without focusing input.
Sourcepub const SET_ICON: Self
pub const SET_ICON: Self
Can set the window icon.
When this is not possible the system specific application metadata icon is used for all windows of the app.
Sourcepub const SET_CURSOR: Self
pub const SET_CURSOR: Self
Can set the window cursor to one of the named CursorIcon.
Sourcepub const SET_CURSOR_IMAGE: Self
pub const SET_CURSOR_IMAGE: Self
Can set the window cursor to a custom image.
Sourcepub const SET_FOCUS_INDICATOR: Self
pub const SET_FOCUS_INDICATOR: Self
Can set attention indicator for the window.
Sourcepub const FOCUS: Self
pub const FOCUS: Self
Can focus input on the window.
This is also true if can the system only shows an attention indicator for the window some times.
Sourcepub const DRAG_MOVE: Self
pub const DRAG_MOVE: Self
Can initiate a window move operation from a mouse press in the content area.
Sourcepub const DRAG_RESIZE: Self
pub const DRAG_RESIZE: Self
Can initiate a window resize operation from a mouse press in the content area.
Sourcepub const OPEN_TITLE_BAR_CONTEXT_MENU: Self
pub const OPEN_TITLE_BAR_CONTEXT_MENU: Self
Can open the system context menu that usually shows on right click on the title bar.
Sourcepub const SYSTEM_CHROME: Self
pub const SYSTEM_CHROME: Self
If operating system provides a window chrome (title bar, resize borders).
Sourcepub const FULLSCREEN: Self
pub const FULLSCREEN: Self
Can make window fullscreen.
Sourcepub const SET_CHROME: Self
pub const SET_CHROME: Self
Can toggle if the system chrome (title bar, resize border) is visible.
Sourcepub const SET_POSITION: Self
pub const SET_POSITION: Self
Can programmatically move window after it is open.
Sourcepub const DISABLE_CLOSE_BUTTON: Self
pub const DISABLE_CLOSE_BUTTON: Self
Can disable close button.
Sourcepub const DISABLE_MINIMIZE_BUTTON: Self
pub const DISABLE_MINIMIZE_BUTTON: Self
Can disable minimize button.
Sourcepub const DISABLE_MAXIMIZE_BUTTON: Self
pub const DISABLE_MAXIMIZE_BUTTON: Self
Can disable maximize button.
Sourcepub const SET_SYSTEM_SHUTDOWN_WARN: Self
pub const SET_SYSTEM_SHUTDOWN_WARN: Self
Can set a system shutdown warning/blocker associated with the window.
Sourcepub const SET_IME_AREA: Self
pub const SET_IME_AREA: Self
Can set the IME area, show virtual keyboard.
Sourceimpl WindowCapability
impl WindowCapability
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl WindowCapability
impl WindowCapability
Sourcepub const fn iter(&self) -> Iter<WindowCapability>
pub const fn iter(&self) -> Iter<WindowCapability>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WindowCapability>
pub const fn iter_names(&self) -> IterNames<WindowCapability>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.